# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # PROJECT TYPE
    def v1_project_project_type_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_project_project_type_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_project_project_type_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_type_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_type_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_type_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_type_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_project_project_type_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_project_project_type_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projecttype-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # PROJECT

    def v1_project_project_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_project_project_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_project_project_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_project_project_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_project_project_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:project-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # PROJECT NUMBER

    def v1_project_project_number_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_project_project_number_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_project_project_number_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_number_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_number_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_number_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_project_project_number_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_project_project_number_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_project_project_number_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-project:projectnumber-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
