# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)

from ... import models


# PROJECT TYPE
class ProjectTypeSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type'
        model = models.ProjectType
        fields = '__all__'


class ProjectTypeListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type_list'
        model = models.ProjectType
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectTypeRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type_retrieve'
        model = models.ProjectType
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectTypeCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type_create'
        model = models.ProjectType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectTypeUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type_update'
        model = models.ProjectType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectTypePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type_partial_update'
        model = models.ProjectType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectTypeEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type_enable'
        model = models.ProjectType
        fields = ()
        response_serializer = ProjectTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ProjectTypeDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type_disable'
        model = models.ProjectType
        fields = ()
        response_serializer = ProjectTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ProjectTypeLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type_light'
        model = models.ProjectType
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# PROJECT
class ProjectSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project'
        model = models.Project
        fields = '__all__'


class ProjectListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_list'
        model = models.Project
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_retrieve'
        model = models.Project
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_create'
        model = models.Project
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_update'
        model = models.Project
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_partial_update'
        model = models.Project
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_enable'
        model = models.Project
        fields = ()
        response_serializer = ProjectRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ProjectDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_disable'
        model = models.Project
        fields = ()
        response_serializer = ProjectRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ProjectLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_light'
        model = models.Project
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# PROJECT NUMBER
class ProjectNumberSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number'
        model = models.ProjectNumber
        fields = '__all__'


class ProjectNumberListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number_list'
        model = models.ProjectNumber
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectNumberRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number_retrieve'
        model = models.ProjectNumber
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectNumberCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number_create'
        model = models.ProjectNumber
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectNumberRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectNumberUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number_update'
        model = models.ProjectNumber
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectNumberRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectNumberPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number_partial_update'
        model = models.ProjectNumber
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ProjectNumberRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ProjectNumberEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number_enable'
        model = models.ProjectNumber
        fields = ()
        response_serializer = ProjectNumberRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ProjectNumberDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number_disable'
        model = models.ProjectNumber
        fields = ()
        response_serializer = ProjectNumberRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ProjectNumberLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number_light'
        model = models.ProjectNumber
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []
